print("import: 'numpy'")
import numpy

print("import: 'numpy.core.multiarray'")
import numpy.core.multiarray

print("import: 'numpy.core.numeric'")
import numpy.core.numeric

print("import: 'numpy.core.umath'")
import numpy.core.umath

print("import: 'numpy.linalg.lapack_lite'")
import numpy.linalg.lapack_lite

print("import: 'numpy.random.mtrand'")
import numpy.random.mtrand

print("import: 'numpy.array_api'")
import numpy.array_api

print("import: 'numpy.array_api.linalg'")
import numpy.array_api.linalg

print("import: 'numpy.ctypeslib'")
import numpy.ctypeslib

print("import: 'numpy.doc'")
import numpy.doc

print("import: 'numpy.doc.constants'")
import numpy.doc.constants

print("import: 'numpy.doc.ufuncs'")
import numpy.doc.ufuncs

print("import: 'numpy.dtypes'")
import numpy.dtypes

print("import: 'numpy.exceptions'")
import numpy.exceptions

print("import: 'numpy.f2py'")
import numpy.f2py

print("import: 'numpy.fft'")
import numpy.fft

print("import: 'numpy.lib'")
import numpy.lib

print("import: 'numpy.lib.format'")
import numpy.lib.format

print("import: 'numpy.lib.mixins'")
import numpy.lib.mixins

print("import: 'numpy.lib.recfunctions'")
import numpy.lib.recfunctions

print("import: 'numpy.lib.scimath'")
import numpy.lib.scimath

print("import: 'numpy.lib.stride_tricks'")
import numpy.lib.stride_tricks

print("import: 'numpy.linalg'")
import numpy.linalg

print("import: 'numpy.ma'")
import numpy.ma

print("import: 'numpy.ma.extras'")
import numpy.ma.extras

print("import: 'numpy.ma.mrecords'")
import numpy.ma.mrecords

print("import: 'numpy.matlib'")
import numpy.matlib

print("import: 'numpy.polynomial'")
import numpy.polynomial

print("import: 'numpy.polynomial.chebyshev'")
import numpy.polynomial.chebyshev

print("import: 'numpy.polynomial.hermite'")
import numpy.polynomial.hermite

print("import: 'numpy.polynomial.hermite_e'")
import numpy.polynomial.hermite_e

print("import: 'numpy.polynomial.laguerre'")
import numpy.polynomial.laguerre

print("import: 'numpy.polynomial.legendre'")
import numpy.polynomial.legendre

print("import: 'numpy.polynomial.polynomial'")
import numpy.polynomial.polynomial

print("import: 'numpy.random'")
import numpy.random

print("import: 'numpy.testing'")
import numpy.testing

print("import: 'numpy.testing.overrides'")
import numpy.testing.overrides

print("import: 'numpy.typing'")
import numpy.typing

print("import: 'numpy.typing.mypy_plugin'")
import numpy.typing.mypy_plugin

print("import: 'numpy.version'")
import numpy.version

